import { useQuery } from '@apollo/client'
import { useCallback, useEffect, useState } from 'react'
import { AutoImportData } from 'src/@types'
import { GetReposQuery } from 'src/api-logic/graphql/generated/schema'
import { GET_REPOS } from 'src/api-logic/graphql/queries/get-repos.query'
import { useRepositoriesContext, useRepositoriesSetState } from 'src/state/contexts'
import { SYNC_REPO_METHOD } from 'src/utils/constants'

const useRepos = () => {
  const [showTable, setShowTable] = useState(false)
  const [runningImports, setRunningImports] = useState<AutoImportData[]>([])
  const [failedImports, setFailedImports] = useState<AutoImportData[]>([])

  const [{ search, rowsRepos, pageRepos }] = useRepositoriesContext()
  const { setTotalRepos } = useRepositoriesSetState()

  const { loading, error, data, refetch } = useQuery<GetReposQuery>(GET_REPOS, {
    variables: { search, first: rowsRepos, offset: (pageRepos * rowsRepos) },
    fetchPolicy: 'no-cache',
    pollInterval: 5000,
  })

  const validateData = useCallback(() => {
    if (!showTable && data?.repos?.totalCount && data?.repos?.totalCount > 0) {
      setShowTable(true)
    }

    setFailedImports(data?.repoImports?.nodes?.filter(imp => imp.importError !== null).map(imp => ({
      id: imp.id,
      name: imp.type === SYNC_REPO_METHOD.GH_USER ? imp.settings.user : imp.settings.org,
      type: imp.type === SYNC_REPO_METHOD.GH_USER ? 'GitHub user' : 'GitHub org',
      error: imp.importError
    })) || [])

    setRunningImports(data?.repoImports?.nodes?.filter(imp => imp.importError === null).map(imp => ({
      id: imp.id,
      name: imp.type === SYNC_REPO_METHOD.GH_USER ? imp.settings.user : imp.settings.org,
      type: imp.type === SYNC_REPO_METHOD.GH_USER ? 'GitHub user' : 'GitHub org'
    })) || [])

    setTotalRepos(data?.repos?.totalCount || 0)
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [data, showTable])

  useEffect(() => {
    !loading && !error && validateData()
  }, [loading, error, validateData])

  useEffect(() => {
    refetch({ search, first: rowsRepos, offset: (pageRepos * rowsRepos) })
  }, [refetch, search, rowsRepos, pageRepos])

  return { showTable, loading, data, runningImports, failedImports, refetch }
}

export default useRepos
